@@ -1,5 +1,7 @@
 cor.conf <-
-function(var1,var2,theo,r.arr=4,p.arr=4) {
+function(var1,var2,theo) {
+  if (length(var1)!=length(var2)) {stop("'var1' and 'var2' lengths differ")}
+  if (theo<(-1) | theo>1) {stop("'theo' must be between -1 and 1")}
   nul<-as.numeric(row.names(table(c(which(is.na(var1)),which(is.na(var2))))))
   var1.2<-if(length(nul)>0) {var1[-nul]} else {var1}
   var2.2<-if(length(nul)>0) {var2[-nul]} else {var2}
@@ -8,12 +10,9 @@ function(var1,var2,theo,r.arr=4,p.arr=4) {
   zeta<-0.5*log((1+theo)/(1-theo))
   u.obs<-abs(z-zeta)*sqrt(length(var1.2)-3)
   p<-min(pnorm(u.obs,0,1),pnorm(u.obs,0,1,lower.tail=FALSE))*2
-  p<-round(p,p.arr)
-  if (p<0.000001) {p<-"< 10e-6"}
-  conform<-data.frame(round(r,r.arr),theo,round(u.obs,3),p,row.names="")
-  names(conform)<-c("observ","thorique","u","p-value")
-  cat(paste("Conformit d'un coefficient de corrlation linaire de Pearson\navec la valeur thorique",theo,"\n\n"))
-  print(conform)
-  cat("\n")
+  conform<-data.frame("observed"=r,"theoretical"=theo,"u"=u.obs,"p.value"=p,"signif"=psignif(p),row.names="")
+  result<-list(r.theo=theo,r.obs=r,u=u.obs,p=p,conform=conform)
+  class(result)<-c("cor.conf","list")
+  return(result)
 }
 
